# UESURIConverter - this components support working with UESURI. Invocation of this component is available
# only for server side scripting, using in client scripts throws exception.
#
# <tt><b>author</b></tt> uni429
#
# <tt><b>since</b></tt> UES6-00
class Ues::Core::Commons::Uri::UESURIConverter
  private_class_method :new

  # <p>Returns normalized UESURI. Normalized form of UESURI is described in artifact
  # <a href="https://uu.unicornuniverse.eu/ues/sesm?SessFree=sues%3A210795%3A47870227">UNI-BT:UES.DOC/URI_V2/HLC</a>.</p>
  #
  # <p>Normalization of an UESURI requires that active territory is the same as territory
  # specified within the normalized UESURI and there is an active transaction.</p>
  #
  # <tt><b>param</b></tt> uri UESURI for normalization.
  #
  # <tt><b>param</b></tt> forceRefresh This parameter enforces usage of persistent storage. If this
  # parameter is set to the value <code>true</code>, UESURI will contain actual codes for
  # every UESURI part. This is useful e.g. if the UESURI will be displayed to user.<br/>
  # If the parameter is set to the <code>false</code> value, UESURI will be created using
  # cache (application performance will be better) and some UESURI part can contain
  # obsoleted code. This is suitable for the most other cases (e.g. when the UESURI will be used for navigation
  # between artifacts - in such case only OID are used).
  #
  # <tt><b>return</b></tt> Normalized UESURI or the <code>null</code> reference if the UESURI cannot be normalized
  # (e.g. the UESURI is ambiguous; there is no persistent object referenced by the UESURI,...).
  #
  # <tt><b>throws</b></tt> InvalidUESURIFormatRTException If UESURI cannot be normalized due to invalid format.
  #
  # <tt><b>author</b></tt> uni429
  #
  # <tt><b>since</b></tt> UES6-00
  def self.getNormalizedURI(uri, forceRefresh=false)
    svc = Java::cz.ues.platform.container.UESComponentFactory.getComponent(Java::cz.ues.core.commons.uri.UESURIConvertor.java_class)
    parUri = Ues::Core::Commons::Uri::UESURI.new(uri).to_java
    res = svc.getNormalizedURI(parUri, forceRefresh)
    return Ues::Core::Commons::Uri::UESURI.new(res)
  end
  class << Ues::Core::Commons::Uri::UESURIConverter
    alias normalized_uri getNormalizedURI
  end

  # Tests, whether is the UESURI in normalized form. Normalized form of an UESURI
  # is specified in artifact <a href="https://uu.unicornuniverse.eu/ues/sesm?SessFree=sues%3A210795%3A47870227">UNI-BT:UES.DOC/URI_V2/HLC</a>.
  #
  # <tt><b>param</b></tt> uri Tested UESURI.
  #
  # <tt><b>return</b></tt> True, when UESURI is normalized, otherwise false.
  #
  # <tt><b>author</b></tt> uni429
  #
  # <tt><b>since</b></tt> UES6-00
  def self.isNormalized(uri)
    svc = Java::cz.ues.platform.container.UESComponentFactory.getComponent(Java::cz.ues.core.commons.uri.UESURIConvertor.java_class)
    parUri = Ues::Core::Commons::Uri::UESURI.new(uri).to_java
    return svc.isNormalized(parUri)
  end
  class << Ues::Core::Commons::Uri::UESURIConverter
    alias is_normalized isNormalized
  end

  # Returns canonical UESURI. Canonical form of UESURI is described in artifact
  # <a href="https://uu.unicornuniverse.eu/ues/sesm?SessFree=sues%3A210795%3A47870227">UNI-BT:UES.DOC/URI_V2/HLC</a>.
  #
  # <tt><b>param</b></tt> uri UESURI for canonicalization.
  #
  # <tt><b>return</b></tt> Canonical UESURI or the <code>null</code> reference if the UESURI cannot be
  # canonicalized (e.g. the UESURI is ambiguous; there is no persistent object referenced by
  # the UESURI,...).
  #
  # <tt><b>throws</b></tt> InvalidUESURIFormatRTException If UESURI cannot be canonicalized due to invalid format.
  #
  # <tt><b>author</b></tt> uni429
  #
  # <tt><b>since</b></tt> UES6-00
  def self.getCanonicalURI(uri)
    svc = Java::cz.ues.platform.container.UESComponentFactory.getComponent(Java::cz.ues.core.commons.uri.UESURIConvertor.java_class)
    parUri = Ues::Core::Commons::Uri::UESURI.new(uri).to_java
    res = svc.getCanonicalURI(parUri)
    return Ues::Core::Commons::Uri::UESURI.new(res)
  end
  class << Ues::Core::Commons::Uri::UESURIConverter
    alias canonical_uri getCanonicalURI
  end

  # Tests, whether is the UESURI in canonical form. Canonical form of an UESURI is specified
  # in artifact <a href="https://uu.unicornuniverse.eu/ues/sesm?SessFree=sues%3A210795%3A47870227">UNI-BT:UES.DOC/URI_V2/HLC</a>.
  #
  # <tt><b>param</b></tt> uri Tested UESURI.
  #
  # <tt><b>return</b></tt> True, when UESURI is in canonical form, otherwise false.
  #
  # <tt><b>author</b></tt> uni429
  #
  # <tt><b>since</b></tt> UES6-00
  def self.isCanonical(uri)
    svc = Java::cz.ues.platform.container.UESComponentFactory.getComponent(Java::cz.ues.core.commons.uri.UESURIConvertor.java_class)
    parUri = Ues::Core::Commons::Uri::UESURI.new(uri).to_java
    return svc.isCanonical(parUri)
  end
  class << Ues::Core::Commons::Uri::UESURIConverter
    alias is_canonical isCanonical
  end

  # Returns evaluated UESURI. Evaluation of UESURI expressions is described in artifact
  # <a href="https://uu.unicornuniverse.eu/ues/sesm?SessFree=sues%3A210795%3A47870227">UNI-BT:UES.DOC/URI_V2/HLC</a>.
  #
  # <tt><b>param</b></tt> uri UESURI for evaluation.
  #
  # <tt><b>return</b></tt> Evaluated UESURI.
  #
  # <tt><b>author</b></tt> uni430
  #
  # <tt><b>since</b></tt> UES6-06
  def self.getEvaluatedURI(uri)
    svc = Java::cz.ues.platform.container.UESComponentFactory.getComponent(Java::cz.ues.core.commons.uri.UESURIConvertor.java_class)
    parUri = Ues::Core::Commons::Uri::UESURI.new(uri).to_java
    res = svc.getEvaluatedURI(parUri)
    return Ues::Core::Commons::Uri::UESURI.new(res)
  end
  class << Ues::Core::Commons::Uri::UESURIConverter
    alias evaluated_uri getEvaluatedURI
  end

  # Tests whether is the UESURI evaluated (expressions are resolved). Evaluation of UESURI
  # expressions is described in artifact <a href="https://uu.unicornuniverse.eu/ues/sesm?SessFree=sues%3A210795%3A47870227">UNI-BT:UES.DOC/URI_V2/HLC</a>.
  #
  # <tt><b>param</b></tt> uri UESURI for evaluation.
  #
  # <tt><b>return</b></tt> True when UESURI is evaluated, otherwise false.
  #
  # <tt><b>author</b></tt> uni430
  #
  # <tt><b>since</b></tt> UES6-06
  def self.isEvaluated(uri)
    svc = Java::cz.ues.platform.container.UESComponentFactory.getComponent(Java::cz.ues.core.commons.uri.UESURIConvertor.java_class)
    parUri = Ues::Core::Commons::Uri::UESURI.new(uri).to_java
    return svc.isEvaluated(parUri)
  end
  class << Ues::Core::Commons::Uri::UESURIConverter
    alias is_evaluated isEvaluated
  end

end
